@@ -20,6 +20,7 @@ ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEAL
 from fantastico import mvc
 from fantastico.locale.language import Language
 from fantastico.middleware.request_context import RequestContext
+from fantastico.routing_engine.custom_responses import RedirectResponse
 from fantastico.settings import SettingsFacade
 from webob.request import Request
 import uuid
@@ -64,7 +65,12 @@ class RequestMiddleware(object):
                     return Language(lang_supported)
                 
         return Language(supported_languages[0])        
-                
+    
+    def _redirect(self, destination, query_params=None):
+        '''This method is used to build a redirect response base on the given arguments.'''
+        
+        return RedirectResponse(destination=destination, query_params=query_params)
+     
     def __call__(self, environ, start_response, uuid_generator=uuid.uuid4):
         request = Request(environ)
         self._build_context(request)
@@ -73,9 +79,11 @@ class RequestMiddleware(object):
         
         if not request.request_id:
             request.request_id = uuid_generator()
+         
+        request.redirect = self._redirect                                
             
         environ["fantastico.current_request_id"] = request.request_id
-        environ["fantastico.request"] = request 
+        environ["fantastico.request"] = request
         
         try:
             return self._app(environ, start_response)
